exfoliate
=========

Exfoliate is the asynchronous HTTP client for developers who prefer synchronous Python.  Enjoy the benefits of a scalable, asynchronous HTTP client without worrying about coroutines or event loops.

Exfoliate is the gentler, more Pythonic way to scrape the web.

For more information, check out the `Github repository <https://github.com/brianjpetersen/exfoliate>`_.
